==> ec2-2.20.89-sources.jar: software/amazon/awssdk/services/ec2/paginators/GetAssociatedIpv6PoolCidrsPublisher.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.ec2.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.concurrent.CompletableFuture;
import java.util.function.Function;
import org.reactivestreams.Subscriber;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.async.SdkPublisher;
import software.amazon.awssdk.core.pagination.async.AsyncPageFetcher;
import software.amazon.awssdk.core.pagination.async.PaginatedItemsPublisher;
import software.amazon.awssdk.core.pagination.async.ResponsesSubscription;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.ec2.Ec2AsyncClient;
import software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsRequest;
import software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse;
import software.amazon.awssdk.services.ec2.model.Ipv6CidrAssociation;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.ec2.Ec2AsyncClient#getAssociatedIpv6PoolCidrsPaginator(software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsRequest)}
 * operation which is a paginated operation. This class is a type of {@link org.reactivestreams.Publisher} which can be
 * used to provide a sequence of {@link software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse}
 * response pages as per demand from the subscriber.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. If there are errors in your request, you will see the failures
 * only after you start streaming the data. The subscribe method should be called as a request to start streaming data.
 * For more info, see {@link org.reactivestreams.Publisher#subscribe(org.reactivestreams.Subscriber)}. Each call to the
 * subscribe method will result in a new {@link org.reactivestreams.Subscription} i.e., a new contract to stream data
 * from the starting request.
 * </p>
 *
 * <p>
 * The following are few ways to use the response class:
 * </p>
 * 1) Using the subscribe helper method
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.GetAssociatedIpv6PoolCidrsPublisher publisher = client.getAssociatedIpv6PoolCidrsPaginator(request);
 * CompletableFuture<Void> future = publisher.subscribe(res -> { // Do something with the response });
 * future.get();
 * }
 * </pre>
 *
 * 2) Using a custom subscriber
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.GetAssociatedIpv6PoolCidrsPublisher publisher = client.getAssociatedIpv6PoolCidrsPaginator(request);
 * publisher.subscribe(new Subscriber<software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse>() {
 * 
 * public void onSubscribe(org.reactivestreams.Subscriber subscription) { //... };
 * 
 * 
 * public void onNext(software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse response) { //... };
 * });}
 * </pre>
 * 
 * As the response is a publisher, it can work well with third party reactive streams implementations like RxJava2.
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #getAssociatedIpv6PoolCidrs(software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class GetAssociatedIpv6PoolCidrsPublisher implements SdkPublisher<GetAssociatedIpv6PoolCidrsResponse> {
    private final Ec2AsyncClient client;

    private final GetAssociatedIpv6PoolCidrsRequest firstRequest;

    private final AsyncPageFetcher nextPageFetcher;

    private boolean isLastPage;

    public GetAssociatedIpv6PoolCidrsPublisher(Ec2AsyncClient client, GetAssociatedIpv6PoolCidrsRequest firstRequest) {
        this(client, firstRequest, false);
    }

    private GetAssociatedIpv6PoolCidrsPublisher(Ec2AsyncClient client, GetAssociatedIpv6PoolCidrsRequest firstRequest,
            boolean isLastPage) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.isLastPage = isLastPage;
        this.nextPageFetcher = new GetAssociatedIpv6PoolCidrsResponseFetcher();
    }

    @Override
    public void subscribe(Subscriber<? super GetAssociatedIpv6PoolCidrsResponse> subscriber) {
        subscriber.onSubscribe(ResponsesSubscription.builder().subscriber(subscriber).nextPageFetcher(nextPageFetcher).build());
    }

    /**
     * Returns a publisher that can be used to get a stream of data. You need to subscribe to the publisher to request
     * the stream of data. The publisher has a helper forEach method that takes in a {@link java.util.function.Consumer}
     * and then applies that consumer to each response returned by the service.
     */
    public final SdkPublisher<Ipv6CidrAssociation> ipv6CidrAssociations() {
        Function<GetAssociatedIpv6PoolCidrsResponse, Iterator<Ipv6CidrAssociation>> getIterator = response -> {
            if (response != null && response.ipv6CidrAssociations() != null) {
                return response.ipv6CidrAssociations().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsPublisher.builder().nextPageFetcher(new GetAssociatedIpv6PoolCidrsResponseFetcher())
                .iteratorFunction(getIterator).isLastPage(isLastPage).build();
    }

    private class GetAssociatedIpv6PoolCidrsResponseFetcher implements AsyncPageFetcher<GetAssociatedIpv6PoolCidrsResponse> {
        @Override
        public boolean hasNextPage(final GetAssociatedIpv6PoolCidrsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public CompletableFuture<GetAssociatedIpv6PoolCidrsResponse> nextPage(
                final GetAssociatedIpv6PoolCidrsResponse previousPage) {
            if (previousPage == null) {
                return client.getAssociatedIpv6PoolCidrs(firstRequest);
            }
            return client.getAssociatedIpv6PoolCidrs(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> ec2-2.31.2-sources.jar: software/amazon/awssdk/services/ec2/paginators/GetAssociatedIpv6PoolCidrsPublisher.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.ec2.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.concurrent.CompletableFuture;
import java.util.function.Function;
import org.reactivestreams.Subscriber;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.async.SdkPublisher;
import software.amazon.awssdk.core.pagination.async.AsyncPageFetcher;
import software.amazon.awssdk.core.pagination.async.PaginatedItemsPublisher;
import software.amazon.awssdk.core.pagination.async.ResponsesSubscription;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.ec2.Ec2AsyncClient;
import software.amazon.awssdk.services.ec2.internal.UserAgentUtils;
import software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsRequest;
import software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse;
import software.amazon.awssdk.services.ec2.model.Ipv6CidrAssociation;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.ec2.Ec2AsyncClient#getAssociatedIpv6PoolCidrsPaginator(software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsRequest)}
 * operation which is a paginated operation. This class is a type of {@link org.reactivestreams.Publisher} which can be
 * used to provide a sequence of {@link software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse}
 * response pages as per demand from the subscriber.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. If there are errors in your request, you will see the failures
 * only after you start streaming the data. The subscribe method should be called as a request to start streaming data.
 * For more info, see {@link org.reactivestreams.Publisher#subscribe(org.reactivestreams.Subscriber)}. Each call to the
 * subscribe method will result in a new {@link org.reactivestreams.Subscription} i.e., a new contract to stream data
 * from the starting request.
 * </p>
 *
 * <p>
 * The following are few ways to use the response class:
 * </p>
 * 1) Using the subscribe helper method
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.GetAssociatedIpv6PoolCidrsPublisher publisher = client.getAssociatedIpv6PoolCidrsPaginator(request);
 * CompletableFuture<Void> future = publisher.subscribe(res -> { // Do something with the response });
 * future.get();
 * }
 * </pre>
 *
 * 2) Using a custom subscriber
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.GetAssociatedIpv6PoolCidrsPublisher publisher = client.getAssociatedIpv6PoolCidrsPaginator(request);
 * publisher.subscribe(new Subscriber<software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse>() {
 * 
 * public void onSubscribe(org.reactivestreams.Subscriber subscription) { //... };
 * 
 * 
 * public void onNext(software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsResponse response) { //... };
 * });}
 * </pre>
 * 
 * As the response is a publisher, it can work well with third party reactive streams implementations like RxJava2.
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #getAssociatedIpv6PoolCidrs(software.amazon.awssdk.services.ec2.model.GetAssociatedIpv6PoolCidrsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class GetAssociatedIpv6PoolCidrsPublisher implements SdkPublisher<GetAssociatedIpv6PoolCidrsResponse> {
    private final Ec2AsyncClient client;

    private final GetAssociatedIpv6PoolCidrsRequest firstRequest;

    private final AsyncPageFetcher nextPageFetcher;

    private boolean isLastPage;

    public GetAssociatedIpv6PoolCidrsPublisher(Ec2AsyncClient client, GetAssociatedIpv6PoolCidrsRequest firstRequest) {
        this(client, firstRequest, false);
    }

    private GetAssociatedIpv6PoolCidrsPublisher(Ec2AsyncClient client, GetAssociatedIpv6PoolCidrsRequest firstRequest,
            boolean isLastPage) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.isLastPage = isLastPage;
        this.nextPageFetcher = new GetAssociatedIpv6PoolCidrsResponseFetcher();
    }

    @Override
    public void subscribe(Subscriber<? super GetAssociatedIpv6PoolCidrsResponse> subscriber) {
        subscriber.onSubscribe(ResponsesSubscription.builder().subscriber(subscriber).nextPageFetcher(nextPageFetcher).build());
    }

    /**
     * Returns a publisher that can be used to get a stream of data. You need to subscribe to the publisher to request
     * the stream of data. The publisher has a helper forEach method that takes in a {@link java.util.function.Consumer}
     * and then applies that consumer to each response returned by the service.
     */
    public final SdkPublisher<Ipv6CidrAssociation> ipv6CidrAssociations() {
        Function<GetAssociatedIpv6PoolCidrsResponse, Iterator<Ipv6CidrAssociation>> getIterator = response -> {
            if (response != null && response.ipv6CidrAssociations() != null) {
                return response.ipv6CidrAssociations().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsPublisher.builder().nextPageFetcher(new GetAssociatedIpv6PoolCidrsResponseFetcher())
                .iteratorFunction(getIterator).isLastPage(isLastPage).build();
    }

    private class GetAssociatedIpv6PoolCidrsResponseFetcher implements AsyncPageFetcher<GetAssociatedIpv6PoolCidrsResponse> {
        @Override
        public boolean hasNextPage(final GetAssociatedIpv6PoolCidrsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public CompletableFuture<GetAssociatedIpv6PoolCidrsResponse> nextPage(
                final GetAssociatedIpv6PoolCidrsResponse previousPage) {
            if (previousPage == null) {
                return client.getAssociatedIpv6PoolCidrs(firstRequest);
            }
            return client.getAssociatedIpv6PoolCidrs(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
